<?php
/*
   Plugin Name: MyanPay WooCommerce(Expresscheckout SOAP)
   Description: Extends WooCommerce to Process Payments with MyanPay's API Method.This is expresscheckout with SOAP. 'When deactivating this module, it will remove all stored token'.
   Version: 1
   Plugin URI: https://www.myanpay.com.mm
   Author: MyanPay
   Note: Tested with WP3.8.2 and WP4.1 , WooCommerce version 2.0.20 and compatible with version 2.2.10
*/

add_action('plugins_loaded', 'woocommerce_wc_myanpay_soap_init', 0);

function woocommerce_wc_myanpay_soap_init() {

   	if ( !class_exists( 'WC_Payment_Gateway' ) ) 
      	return;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * WC_Gateway_Myanpay Class.
 */
class WC_Gateway_Myanpay_Soap extends WC_Payment_Gateway {

	/** @var bool Whether or not logging is enabled */
	public static $log_enabled = false;

	/** @var WC_Logger Logger instance */
	public static $log = false;

	/**
	 * Constructor for the gateway.
	 */
	public function __construct() {
		$this->id                 = 'myanpay_soap';
		$this->has_fields         = false;
		$this->order_button_text  = __( 'Proceed to MyanPay', 'woocommerce' );
		$this->method_title       = __( 'MyanPay Express', 'woocommerce' );
		$this->liveurl			  = 'https://www.myanpay.com.mm';
		$this->testurl			  = 'https://www.myanpay-virtualbox.com';
		$this->icon               = WP_PLUGIN_URL . "/" . plugin_basename(dirname(__FILE__)) . '/images/MyanPayLogo.jpg';
		$this->method_description = sprintf( __( 'Myanpay sends customers to MyanPay to enter their payment information.', 'woocommerce' ), '<a href="' . admin_url( 'admin.php?page=wc-status' ) . '">', '</a>' );
		$this->supports           = array(
			'products',
			'refunds'
		);
		// Setup available currency codes.
		$this->available_currencies = array( 'MMK');

		// Load the form fields.
		$this->init_form_fields();

		// Load the settings.
		$this->init_settings();
		


	// Define user set variables
		$this->title          = $this->get_option( 'title' );
		$this->description    = $this->get_option( 'description' );
		$this->enabled		  = $this->get_option( 'enabled' );
		$this->apiusername    = $this->get_option( 'apiusername' );
		$this->apipassword    = $this->get_option( 'apipassword' );
		$this->apisignature   = $this->get_option( 'apisignature' );
		$this->order_status   = $this->get_option( 'order_status' );
		$this->mpaymode   	  = $this->get_option('mpaymode') == 'test' ? $this->testurl : $this->liveurl;
		$this->headerlogo     = $this->get_option( 'headerlogo' );
		$this->brandname	  = $this->get_option( 'brandname');
		$this->sellerphone 	  = $this->get_option( 'sellerphone' );
		
		self::$log_enabled    = $this->debug;
		//add_filter( 'woocommerce_locate_template', 'myplugin_woocommerce_locate_template', 10, 3 );
		add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
		add_action( 'woocommerce_receipt_' . $this->id, array( $this, 'receipt_page' ) );
		add_action( 'woocommerce_thankyou_myanpay', array( $this, 'thankyou_page' ) );
		
}

	public function init_form_fields() {
		$this->form_fields = include( 'includes/settings-myanpay.php' );
	}
	 /**
     * is_valid_for_use()
     *
     * Check if this gateway is enabled and available in the base currency being traded with.
     *
     * @since 1.0.0
     */
	public function is_valid_for_use() {
		$is_available          = false;
      
		if ($this->apiusername && $this->apipassword && $this->apisignature) {
			$is_available = true;
		}
        return $is_available;
	}


    
		public function admin_options(){
			echo '<h3>'.__('MyanPay Express Checkout(SOAP) Payment Method Configuration', 'woocommerce').'</h3>';
			echo '<p>'.__('MyanPay is most popular payment gateway for online payment processing').'</p>';
			echo '<table class="form-table">';
			$this->generate_settings_html();
			echo '<tr><td>(Module Version 1.0.4)</td></tr></table>';
		}

		/**
	 * Generate the MyanPay button link.
	 *
	 * @since 1.0.0
	 */
    public function generate_myanpay_form( $order_id ) {
		$order         = wc_get_order( $order_id );

		return '<form action="' . $this->get_return_url($order) . '" method="post" id="myanpay_payment_form">
				<input type="submit" class="button-alt" id="submit_myanpay_payment_form" value="' . __( 'Pay with MyanPay', 'Woocommerce' ) . '" /> &nbsp;&nbsp;&nbsp;&nbsp;<a class="button-alt" href="' . $order->get_cancel_order_url() . '">' . __( 'Cancel order', 'Woocommerce' ) . '</a>
				
			</form>';
	}

	/**
	 * Process the payment and return the result.
	 *
	 * @since 1.0.0
	 */
	public function process_payment( $order_id ) {
		global $woocommerce;
 		 wc_get_template( 'checkout/mp.php' ); 
        $order = new WC_Order($order_id);
	
		  $pageURL = 'http';
			if (isset($_SERVER["HTTPS"]) && $_SERVER["HTTPS"] == "on")
			{
				$pageURL .= "s";
			}
			$pageURL .= "://";
			
			if ($_SERVER["SERVER_PORT"] != "80")
			{
				$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"];
			} else {
				$pageURL .= $_SERVER["SERVER_NAME"];
			}
			$redirect_url = ($this -> redirect_page_id=="" || $this -> redirect_page_id==0)?get_site_url() . "/":get_permalink($this -> redirect_page_id);
			$url=$redirect_url;
		
			//$returnURL = $order->get_checkout_payment_url( true );
			$returnURL = $order->get_checkout_payment_url( true );
			$cancelURL =$url . "/" . 'myanpay.php';

		//echo $returnURL;exit;
if (isset($this->available_currencies )){
		
 	if( !in_array( get_woocommerce_currency(), $this->available_currencies)){
		
		$msgTitle = ' The Myanpay Express Payment Server has returned a currency error! ';
			wc_add_notice(__($msgTitle.'<br>Invalid currency code.<br> Myanpay Express Payment System accept only Myanmar Kyat.<br>Please change your currency to Myanmar Kyat (MMK or KS) and retry the request.', 'woocommerce'), 'error');
			$order->add_order_note( sprintf( __( ' Invalid currency code.<br> Myanpay Express Payment System accept only Myanmar Kyat.<br>Please change your currency to Myanmar Kyat (MMK or KS) and retry the request.', 'myanpay-for-woocommerce', 'woocommerce' ) ) );
			$order->update_status( 'failed');
	
	}
	else{
		$auth = new stdClass();
		$auth->ApiUserName = $this->apiusername;
		$auth->ApiPassword = $this->apipassword;
		$auth->ApiSignature = $this->apisignature;
	
		/*+++++++++++++++[ Start Get Data Object ]+++++++++++++++*/
$w=0;
$i=0;
$AllproductData=array();

		  $items = $woocommerce->cart->get_cart();
		 	
		foreach($items as $item => $values) 
		  { 
			    //print_r($item); 
		
				 $_product = $values['data']->post;
				  $subtotal=$values['line_subtotal'];
				 $qty=(int)$values['quantity'];
				 $sub =$subtotal / $qty; 
				 $str = $str . "paymentRequest_ItemNumber$w=H-10$w" .
							"paymentRequest_ItemName$w=" . $_product->post_title .
							"paymentRequest_ItemAmt$w=" . $values['line_subtotal'] .
							"paymentRequest_ItemQty$w=" . (int)$values['quantity'] ;
		     $w++;
					
					$PaymentRequestItem = new stdClass();
					$PaymentRequestItem->PaymentRequest_ItemNumber = 'H0'.$w;
					$PaymentRequestItem->PaymentRequest_ItemName =  $values['data']->post->post_title;
					$PaymentRequestItem->PaymentRequest_ItemAmt = $sub;
					$PaymentRequestItem->PaymentRequest_ItemQty = (int)$values['quantity'];
					$AllproductData[$i]=$PaymentRequestItem;
					$i++;
		   }
		    
		 /*
		 *
		 checking coupon
		 *
		 */ 
			//$w++;
			$discount = $woocommerce->cart->discount_cart;
			if ($discount != 0){
			//echo "discount=". $discount;
			$PaymentRequestItem = new stdClass();
			$PaymentRequestItem->PaymentRequest_ItemNumber = 'D01';
			$PaymentRequestItem->PaymentRequest_ItemName =  'Discount';
			$PaymentRequestItem->PaymentRequest_ItemAmt = (string)-$woocommerce->cart->discount_cart;
			$PaymentRequestItem->PaymentRequest_ItemQty = 1;
			$AllproductData[$i]=$PaymentRequestItem;
			$i++;
			}
 	
				 /*
		 *
		 checking tax
		 *
		 */
		 
			$tax=$woocommerce->cart->tax_total;
			if(isset($tax))
			{
			$PaymentRequestItem = new stdClass();
			$PaymentRequestItem->PaymentRequest_ItemNumber = 'T01';
			$PaymentRequestItem->PaymentRequest_ItemName =  'Tax';
			$PaymentRequestItem->PaymentRequest_ItemAmt = $tax;
			$PaymentRequestItem->PaymentRequest_ItemQty = 1;
			$AllproductData[$i]=$PaymentRequestItem;
			}
  //exit;
		
		$totalAmt =  (string)$order->order_total;
		echo "total amt =".$totalAmt;
		$_SESSION['setAmt'] = $totalAmt;
		//var_dump($item_name['PaymentRequest_ItemName'.$w]);exit;
		$PaymentObject = new stdClass();
		$PaymentObject->PaymentRequest_Amt = $totalAmt;
		$PaymentObject->PaymentRequest_ItemTotalAmt = $totalAmt;
		$PaymentObject->PaymentRequest_PaymentActionID = 1;
		$PaymentObject->PaymentItemDetailsInfoObjects=$AllproductData;
		//var_dump(array($AllproductData));//exit;
		$_SESSION['SetPaymentDetail'] = $PaymentObject;
		//$oo = count((array)$PaymentObject);
		//$oo--;
		//echo "count =".$oo;
		//var_dump($PaymentObject);exit;
		$setMethod = array("ApiMethod" => "SetExpressCheckout",
			"ApiVersion" => "1.1",		
			"MyanPayExpressCheckOutApiCredentialObject"=>$auth,
			"ReturnUrl" => $returnURL,
			"CancelUrl" => $cancelURL,		
			"PaymentAction" => "Sale",
			"PaymentDetailsInfoObject" => $PaymentObject);
		
		$setParameter = array("setExpressCheckoutReq" => $setMethod);
		//var_dump($setParameter);exit;
		/*+++++++++++++++[ End Combine Data Object ]+++++++++++++++*/

		/*+++++++++++++++[ Start SOAP ]+++++++++++++++*/
		$soapURL = "https://www.myanpay-virtualbox.com/Soap/EcService.svc?wsdl";
		$options = array(
			"soap_version" => SOAP_1_2,
			"expection"=> true,    
			"useWSA"=>true,
		);
		$client = new SoapClient($soapURL, $options);
		
		$actionHeader[] = new SoapHeader('http://www.w3.org/2005/08/addressing','Action','http://tempuri.org/IEcService/SetExpressCheckout',true);
		$actionHeader[] = new SoapHeader("http://www.w3.org/2005/08/addressing", 'To', 'https://www.myanpay.com.mm/Soap/EcService.svc',true);
		$client->__setSoapHeaders($actionHeader);
		
		try{	
			$setResult = $client->SetExpressCheckout($setParameter);
			//$_SESSION['response'] = $setResult;
			//var_dump($setResult); exit;
			$ack = $setResult->SetExpressCheckoutResult->Ack;
			$token = $setResult->SetExpressCheckoutResult->Token;
			$errMsg = $setResult->SetExpressCheckoutResult->ErrorLongMessage;
			if($ack=="success")
			{
				
				$strTime = '[ ' . date("h:i:s A") . ' ] - ';
				$order->add_order_note( sprintf( __($strTime.'Start MyanPay ExpressCheckout', 'myanpay-for-woocommerce', 'woocommerce' ) ) );
				$order->update_status( 'pending');
		
				$this->send_email_notification(
				sprintf( __( 'Payment for order started', 'woocommerce' ) ),
				sprintf( __( 'Order #%s - Start MyanPay Express Checkout %s', 'woocommerce' ), $order->get_order_number(), $posted['reason_code'])
			);

				if ($this->mpaymode == 'https://www.myanpay.com.mm')
				{
					$myanpayURL = "https://www.myanpay.com.mm/Personal/ExpressCheckout/ExpressCheckoutLogin.aspx?cmd=express-checkout&token=" .$token;
				} else  {	
					$myanpayURL = "https://www.myanpay-virtualbox.com/Personal/ExpressCheckout/ExpressCheckoutLogin.aspx?cmd=express-checkout&token=" .$token;
				}
				return array('result' => 'success', 'redirect' => add_query_arg('order',$order->id, add_query_arg('key', $order->order_key, $myanpayURL)));
				
				exit;
			} else  {				
				foreach($setResult->SetExpressCheckoutResult as $key => $value) 
				{
					if($key == 'ErrorLongMessage')
					{
						wc_add_notice(__('MyanPay Set API Error <br>'.$value), 'error');
						
					}
					if($key == 'ErrorShortMessage')
					{
						$order->add_order_note( sprintf( __($value, 'myanpay-for-woocommerce', 'woocommerce' ) ) );
					}
				}
			$order->update_status( 'failed');
			exit;
			}
		}catch(SoapFault $e){
			$soapErrCode = $e->faultcode;
			$soapErrMessage = $e->faultstring;
			$nvpErr = "<b> The MyanPay SOAP API has returned an error! </b> <br>";
			$nvpErr.= "Error Code = $soapErrCode <br>";
			$nvpErr.= "Error Message = $soapErrMessage <br> ";
			wc_add_notice(__($nvpErr, 'myanpay-for-woocommerce'), 'error');
			$order->add_order_note( sprintf( __($nvpErr, 'woocommerce' ) ) );
			$order->update_status( 'failed');
			exit;
		   }

		}
		 
	}
	 else{
		   $msgTitle = ' The Myanpay Payment needs Myanmar Kyat ';
			wc_add_notice(__($msgTitle.'<br>You need to add Myanmar Kyat to pay with MyanPay.So, please add Myanmar Kyat to your currency setting.', 'woocommerce'), 'error');
			$order->add_order_note( sprintf( __( 'You need to add Myanmar Kyat to pay with MyanPay.So, please add Myanmar Kyat to your currency setting.', 'myanpay-for-woocommerce', 'woocommerce' ) ) );
			$order->update_status( 'failed');
		   }
}
	 /**
	 * Reciept page.
	 *
	 * Display text and a button to direct the user to MyanPay.
	 *
	 * @since 1.0.0
	 */
	public function receipt_page( $order_id ) {
		session_start();
		
		global $woocommerce;
		$order = new WC_Order($order_id);
		
		$redirect_url = ($this -> redirect_page_id=="" || $this -> redirect_page_id==0)?get_site_url() . "/":get_permalink($this -> redirect_page_id);
		
		$this->apiusername    = $this->get_option( 'apiusername' );
		$this->apipassword    = $this->get_option( 'apipassword' );
		$this->apisignature   = $this->get_option( 'apisignature' );
		
		$auth = new stdClass();
		$auth->ApiUserName = $this->apiusername;
		$auth->ApiPassword = $this->apipassword;
		$auth->ApiSignature = $this->apisignature;
		
		/*+++++++++++++++[ Start MPay Data Combine Object ]+++++++++++++++*/
		$getMethod = array("ApiMethod" => "GetExpressCheckout",
			"ApiVersion" => "1.1",
			"MyanPayExpressCheckOutApiCredentialObject"=>$auth,
			"Token"=> $_REQUEST['token']);		
		$getParameter = array("getExpressCheckoutReq" => $getMethod);
		/*+++++++++++++++[ End MPay Data Combine Object ]+++++++++++++++*/
		//var_dump($getParameter);
		/*+++++++++++++++[ Start SOAP ]+++++++++++++++*/
		$soapURL = "https://www.myanpay-virtualbox.com/Soap/EcService.svc?wsdl";
		$options = array(
			"soap_version" => SOAP_1_2,
			"expection"=> true,
			"useWSA"=>true,
		);
		$client = new SoapClient($soapURL, $options);
		
		$actionHeader[] = new SoapHeader('http://www.w3.org/2005/08/addressing','Action','http://tempuri.org/IEcService/GetExpressCheckout',true);
		$actionHeader[] = new SoapHeader("http://www.w3.org/2005/08/addressing", 'To', 'https://www.myanpay.com.mm/Soap/EcService.svc',true);
		$client->__setSoapHeaders($actionHeader);
		
		try{
			$getResult = $client->GetExpressCheckout($getParameter);
			$_SESSION['getResult'] = $getResult;	
			//var_dump($getResult); 
			$ack = $getResult->GetExpressCheckoutResult->Ack;
			if($ack=="success")
			{
				echo "<style>
						table{
  							border-collapse: separate !important;
 						 	}
						table tr{
  							border-bottom: 1px solid #DDD !important;
								}	 
					</style>";
					
				echo "<table border='1'>";
				echo "<tr bgcolor='#999999'>";
				echo "<td style='padding-left:10px;'>Item Name</td>";
				echo "<td align='center'>Item Number</td>";
				echo "<td align='center'>Quantity</td>";
				echo "<td align='center'>Item Amount</td>";				
				echo "</tr>";
				
				$getItem = $getResult->GetExpressCheckoutResult->PaymentDetailsInfo->EcInvoiceItemDeepObjects->ECInvoiceItemDeepObject;
				$name = $getResult->GetExpressCheckoutResult->PayerInfo->DisplayName;
				$email = $getResult->GetExpressCheckoutResult->PayerInfo->PrimaryEmailAddress;
				$phone = $getResult->GetExpressCheckoutResult->PayerInfo->PhoneNumber;
				$status = $getResult->GetExpressCheckoutResult->PayerInfo->PayerStatus;
				$totalAmt = $getResult->GetExpressCheckoutResult->PaymentDetailsInfo->ECinvoice_ItemTotalAmt;
				$getItem = $getResult->GetExpressCheckoutResult->PaymentDetailsInfo->EcInvoiceItemDeepObjects->ECInvoiceItemDeepObject;
				$login = $getResult->GetExpressCheckoutResult->Ack;
				$login_time = $getResult->GetExpressCheckoutResult->TimeStamp;
				
				$payerID = $getResult->GetExpressCheckoutResult->PayerInfo->PayerID;
				$token = $getResult->GetExpressCheckoutResult->Token;
				$_SESSION['payerID'] = $payerID;
				$_SESSION['token'] = $token;
				
				//var_dump($getItem);
				
				foreach($getItem as $value) 
                    {
						//$ecName=$value->ECinvoiceItem_Name;
						//$ecNumber=$value->ECinvoiceItem_Number;
						//$ecQty=$value->ECinvoiceItem_Qty;
						//$ecAmt=(float)$value->ECinvoiceItem_Amt;
                    	//$Total = $value->ECinvoiceItem_Amt * $value->ECinvoiceItem_Qty;
						
						$ecName=$value->ECinvoiceItem_Name;
						$ecNumber=$value->ECinvoiceItem_Number;
						$ecQty=$value->ECinvoiceItem_Qty;
						$ecAmt=(float)$value->ECinvoiceItem_Amt;
                    	$Total = $value->ECinvoiceItem_Amt * $value->ECinvoiceItem_Qty;
						
                        echo "<tr>" ;
                        echo "<td >" . $ecName . "</td>";                        
                        echo "<td align='center'>" . $ecNumber. "</td>";                       
                        echo "<td align='center'>" . $ecQty . "</td>";                        
                        echo "<td align='center'>" . $ecAmt . "</td>";   						                             
                        echo "</tr>" ;
                    }    
				echo "</table> <br/>";
				echo "<table style='width:30%; float: right;' border=1>";
				echo "<tr><td colspan=2 bgcolor=#999999 align='center'> MyanPay Express CheckOut Information</td></tr>";
				echo "<tr><td align='center'> Name</td><td style='padding-left:10px;'>".$name."</td></tr>";
				echo "<tr><td align='center'> Email</td><td style='padding-left:10px;'>".$email."</td></tr>";
				echo "<tr><td align='center'> Phone</td><td style='padding-left:10px;'>".$phone."</td></tr>";
				echo "<tr><td align='center'> Status</td><td style='padding-left:10px;'>".$status."</td></tr>";
				echo "<tr><td align='center'> Login</td><td style='padding-left:10px;'>".$login."</td></tr>";
				echo "<tr><td align='center'> LoginTime</td><td style='padding-left:10px;'>".$login_time."</td></tr>";
				echo "</table>";
			
				echo "<table style='width:70%;float:left'>";
				echo "<tr><td><img style='float:left; margin: 0px 10px 5px 0px;' alt='MyanPay' src='".$redirect_url."wp-content/plugins/myanpay/images/MyanPayLogo.jpg'><br>You have chosen to pay with myanpay. Here is a short summary of your order:</td></tr>";
				echo "<tr><td style='margin-top:5px;'> - The total amount of your order is " .$totalAmt. "</td></tr>";
				echo "<tr><td> - We accept the following currency to be sent by MyanPay: Myanmar Kyat</td></tr>";
				echo "<tr><td> - Please confirm your order by clicking Pay With MyanPay</td></tr>";
				echo "</table>";
				
				$strTime = '[ ' . date("h:i:s A") . ' ] - ';
				$order->add_order_note( sprintf( __($strTime.'Get MyanPay Buyer Name = ' .$name . ', Email = ' . $email . ', Phone = ' . $phone . ' is ' . $status,'myanpay-for-woocommerce', 'woocommerce' ) ) );
	    		$order->update_status( 'pending');

			$this->send_email_notification(
				sprintf( __( 'Payment for order confirm', 'woocommerce' ) ),
				sprintf( __("Order #%s - Get MyanPay Buyer Name =  $name  , Email =  $email , Phone =   $phone  is  $status %s", 'woocommerce'), $order->get_order_number(), $posted['reason_code'])
			);
			
			}

			 else  {
				foreach($getResult->GetExpressCheckoutResult as $key => $value) 
				{
					if($key == 'ErrorLongMessage')
					{
						wc_add_notice(__('MyanPay Set API Error <br>'.$value), 'error');
					}
					if($key == 'ErrorShortMessage')
					{
						$order->add_order_note( sprintf( __($value, 'myanpay-for-woocommerce', 'woocommerce' ) ) );
					}
				}
			$order->update_status( 'failed');
			exit;
			}
			
		}catch(SoapFault $e){
			$soapErrCode = $e->faultcode;
			$soapErrMessage = $e->faultstring;
			$nvpErr = "<b> The MyanPay SOAP API has returned an error! </b> <br>";
			$nvpErr.= "Error Code = $soapErrCode <br>";
			$nvpErr.= "Error Message = $soapErrMessage <br> ";
			wc_add_notice(__($nvpErr, 'myanpay-for-woocommerce'), 'error');
			$order->add_order_note( sprintf( __($nvpErr, 'woocommerce' ) ) );
			$order->update_status( 'failed');
			exit;
		}
		/*+++++++++++++++[ End SOAP ]+++++++++++++++*/
	
		echo $this->generate_myanpay_form( $order );

	}
	
	 /**
     * Output for the order received page.
     */
	public function thankyou_page($order_id ) {
		
		session_start();
		
		global $woocommerce;
		$order = new WC_Order($order_id);
		
		$redirect_url = ($this -> redirect_page_id=="" || $this -> redirect_page_id==0)?get_site_url() . "/":get_permalink($this -> redirect_page_id);

		$getResponse = $_SESSION['getResult'];
		$getAmt = $getResponse->GetExpressCheckoutResult->PaymentDetailsInfo->ECinvoice_Amt;
		$getItemTotalAmt = $getResponse->GetExpressCheckoutResult->PaymentDetailsInfo->ECinvoice_ItemTotalAmt;
		$payerID = $getResponse->GetExpressCheckoutResult->PayerInfo->PayerID;
		$token = $getResponse->GetExpressCheckoutResult->Token;
		$setAmt = $_SESSION['setAmt'];
		
		$item = $getResponse->GetExpressCheckoutResult->PaymentDetailsInfo->EcInvoiceItemDeepObjects->ECInvoiceItemDeepObject;
		foreach($item as $key => $value) {
					if($key == 'ECinvoiceItem_Name'){
						$Name = $value ;
					}
				 }
				foreach($item as $key => $value) {
					if($key == 'ECinvoiceItem_Number'){
						 $Number = $value ;
					}
					if($key == 'ECinvoiceItem_Qty'){
						$Qty = $value ;
					}
				  }
				foreach($item as $key => $value) {
					if($key == 'ECinvoiceItem_Amt'){
						$Amt = $value ;
					}
				 }
				 
			$PaymentData = array();
			
			$PaymentRequestItem = new stdClass();
			$PaymentRequestItem->PaymentRequest_ItemName =  $Name;
			$PaymentRequestItem->PaymentRequest_ItemNumber = $Number;
			$PaymentRequestItem->PaymentRequest_ItemQty = $Qty;
			$PaymentRequestItem->PaymentRequest_ItemAmt = $Amt;
			$PaymentData[$key]= $PaymentRequestItem;
		
		//var_dump($PaymentData);
		$PaymentObject = new stdClass();
		$PaymentObject->PaymentRequest_Amt = $getAmt;
		$PaymentObject->PaymentRequest_ItemTotalAmt = $getAmt;
		$PaymentObject->PaymentRequest_PaymentActionID = 1;
		$PaymentObject->PaymentItemDetailsInfoObjects = $PaymentData;
		//var_dump($PaymentObject);
		$this->apiusername    = $this->get_option( 'apiusername' );
		$this->apipassword    = $this->get_option( 'apipassword' );
		$this->apisignature   = $this->get_option( 'apisignature' );
		
		$auth = new stdClass();
		$auth->ApiUserName = $this->apiusername;
		$auth->ApiPassword = $this->apipassword;
		$auth->ApiSignature = $this->apisignature;

	
		$doMethod = array("ApiMethod" => "DoExpressCheckout",
						"ApiVersion" => "1.1",
		 				"MyanPayExpressCheckOutApiCredentialObject"=>$auth,
						"PayerID"=> $payerID,
						"Token"=> $token,
						"PaymentDetailsInfoObject" => $PaymentObject);
		//====================================
			$doParameter = array("doExpressCheckoutReq" => $doMethod);
			//var_dump($doParameter);
		/*+++++++++++++++[ End MPay Data Combine Object ]+++++++++++++++*/
		
		/*+++++++++++++++[ Start SOAP ]+++++++++++++++*/
		$soapURL = "https://www.myanpay-virtualbox.com/Soap/EcService.svc?wsdl";
		$options = array(
			"soap_version" => SOAP_1_2,
			"expection"=> true,
			"useWSA"=>true,
		);
		$client = new SoapClient($soapURL, $options);
		
		$actionHeader[] = new SoapHeader('http://www.w3.org/2005/08/addressing','Action','http://tempuri.org/IEcService/DoExpressCheckout',true);
		$actionHeader[] = new SoapHeader("http://www.w3.org/2005/08/addressing", 'To', 'https://www.myanpay.com.mm/Soap/EcService.svc',true);
		$client->__setSoapHeaders($actionHeader);
		
		try{
			$doResult = $client->DoExpressCheckout($doParameter);
			$_SESSION['doResult'] = $doResult;	
			//var_dump($doResult); exit;
			$totalAmt = $doResult->DoExpressCheckoutResult->MyanPayTransactionObject->GrossAmount;
			$transation_id = $doResult->DoExpressCheckoutResult->MyanPayTransactionObject->MyanPayTransactionID;
			$type = $doResult->DoExpressCheckoutResult->MyanPayTransactionObject->MyanPayTransactionTypeName;
			$orderTime = $doResult->DoExpressCheckoutResult->TimeStamp . ' . ' . $doResult->DoExpressCheckoutResult->OrderTime;
			$statusName = $doResult->DoExpressCheckoutResult->MyanPayTransactionObject->MyanPayTransactionPaymentStatusName;
			$this->title          = $this->get_option( 'title' );
			$title = $this->title;
		
			$ack = $doResult->DoExpressCheckoutResult->Ack;
			$token = $doResult->DoExpressCheckoutResult->Token;
			$errMsg = $doResult->DoExpressCheckoutResult->ErrorLongMessage;
			if($ack=="success")
			{
				
				$strTime = '[ ' . date("h:i:s A") . ' ] - ';
				$order->add_order_note( sprintf( __($strTime .'Payment received '.$setAmt.'Ks with MyanPay Transaction ID - '. $transation_id,'myanpay-for-woocommerce', 'woocommerce' ) ) );
				$this->order_status    = $this->get_option( 'order_status' );
				$order->update_status($this->order_status);
				
				$this->send_email_notification(
				sprintf( __( 'Payment for order completed', 'woocommerce' ) ),
				sprintf( __(" Order #%s - Payment received  $setAmt Ks with MyanPay Transaction ID -  $transation_id  %s", 'woocommerce' ), $order->get_order_number(), $posted['reason_code'])
			);
				
				echo "<table class='display'> <tbody> ";
				echo "<tr><th align='center'> MyanPay Success Information </th></tr>";
				echo "<tr><td><img style='float:left; margin: 0px 10px 5px 0px;' alt='MyanPay' src='".$redirect_url."wp-content/plugins/myanpay/images/MyanPayLogo.jpg'><br>Your order on Myanpay is : ".$statusName."</td></tr>";
				echo "<tr><td>You have chosen " . $title . "</td></tr>";
				echo "<tr><td>The total amount of your transaction is : Ks".$totalAmt."</td></tr>";
				echo "<tr><td>Your Myanpay Transaction ID is : ".$transation_id."</td></tr>";
				echo "<tr><td>Your transaction type is  : ".$type."</td></tr>";
				echo "<tr><td>Your time stamp is : ".$orderTime."</td></tr>";
				echo "<tr><td>Your Order will be sent very soon.</td></tr>";
				echo "</tbody></table> <br> ";

				
			} else  {
				foreach($doResult->DoExpressCheckoutResult as $key => $value) 
				{
					if($key == 'ErrorLongMessage')
					{
						wc_add_notice(__('MyanPay Set API Error <br>'.$value), 'error');
					}
					
					if($key == 'ErrorShortMessage')
					{
						$order->add_order_note( sprintf( __($value, 'woocommerce' ) ) );
					}
				}
			
			$order->update_status( 'failed');
			wp_redirect($redirect_url.'cart');
			exit;
			}
		}catch(SoapFault $e){
			$soapErrCode = $e->faultcode;
			$soapErrMessage = $e->faultstring;
			$nvpErr = "<b> The MyanPay SOAP API has returned an error! </b> <br>";
			$nvpErr.= "Error Code = $soapErrCode <br>";
			$nvpErr.= "Error Message = $soapErrMessage <br> ";
			wc_add_notice(__($nvpErr, 'woocommerce'), 'error');
			$order->add_order_note( sprintf( __($nvpErr, 'woocommerce' ) ) );
			$order->update_status( 'failed');
			wp_redirect($redirect_url.'cart');
			exit;
		}
		/*+++++++++++++++[ End SOAP ]+++++++++++++++*/
	}
protected function send_email_notification( $subject, $message ) {
		$new_order_settings = get_option( 'woocommerce_processing_order_settings', array() );
		$mailer             = WC()->mailer();
		$message            = $mailer->wrap_message( $subject, $message );
		
		$mailer->send( ! empty( $processing_order_settings['recipient'] ) ? $processing_order_settings['recipient'] : get_option( 'admin_email' ), strip_tags( $subject ), $message );
	}
	
	protected function get_order_item_names( $order ) {
		$item_names = array();

		foreach ( $order->get_items() as $item ) {
			$item_names[] = $item['name'].'x'.$item['qty'];
		}

		return implode( ', ', $item_names );
	}
} 
  /**
    * Add this Gateway to WooCommerce
   **/
   	function woocommerce_add_myanpay_soap_gateway($methods) 
   	{
      	$methods[] = 'WC_Gateway_Myanpay_Soap';
      	return $methods;
   	}

   	add_filter('woocommerce_payment_gateways', 'woocommerce_add_myanpay_soap_gateway' );

}
